@@ -7,6 +7,7 @@ from lru import LRU
 from pampy import match
 from tabulate import tabulate
 
+import hashlib
 
 @dataclass()
 class RuleEdge:
@@ -131,7 +132,6 @@ class AutoRuleBook:
         self._init_non_picklable()
 
     def __add__(self, other: Union["AutoRuleBook", IRecursiveRule, IRule]):
-        import hashlib
         return match(other,
                      IRule, self.add_rule,
                      IRecursiveRule, self.add_recursive_rule,
@@ -200,7 +200,8 @@ class AutoRuleBook:
                 return res
 
     def __hash__(self):
-        return self.id
+        # ohh id must return an integer, okey
+        return int(hashlib.md5(self.id).hexdigest(),16)
 
     def __repr__(self):
         t1 = tabulate(enumerate(self.rules), headers="index rules".split())
